@@ -10,6 +10,7 @@ import pickle
 import sys
 from collections import deque
 from io import StringIO
+from pathlib import Path
 from typing import TYPE_CHECKING, overload
 
 from docutils.parsers.rst import roles
@@ -37,7 +38,6 @@ from sphinx.util.tags import Tags
 if TYPE_CHECKING:
     import os
     from collections.abc import Callable, Collection, Iterable, Sequence, Set
-    from pathlib import Path
     from typing import IO, Any, Final, Literal
 
     from docutils import nodes
@@ -1484,6 +1484,9 @@ class Sphinx:
         A JavaScript file can be added to the specific HTML page when an extension
         calls this method on :event:`html-page-context` event.
 
+        .. seealso::
+           :meth:`add_static_dir` for copying static files to the output directory
+
         .. versionadded:: 0.5
 
         .. versionchanged:: 1.8
@@ -1549,6 +1552,9 @@ class Sphinx:
         A CSS file can be added to the specific HTML page when an extension calls
         this method on :event:`html-page-context` event.
 
+        .. seealso::
+           :meth:`add_static_dir` for copying static files to the output directory
+
         .. versionadded:: 1.0
 
         .. versionchanged:: 1.6
@@ -1572,6 +1578,42 @@ class Sphinx:
                 filename, priority=priority, **kwargs
             )
 
+    def add_static_dir(self, path: str | os.PathLike[str]) -> None:
+        """Register a static directory to include in HTML output.
+
+        The given directory's contents will be copied to the ``_static``
+        directory during an HTML build. Files from extension static directories
+        are copied after theme static files and before any directories from
+        the user-configured ``html_static_path`` setting.
+
+        Sphinx has built-in support for ``static/`` directories in themes;
+        theme developers should only use this method to register further
+        directories to be copied.
+
+        :param path: The path to a directory containing static files.
+                     This is typically relative to the extension's package
+                     directory.
+
+        Example::
+
+            from pathlib import Path
+
+            def setup(app):
+                # All files in this directory are copied to _static/,
+                # preserving the subdirectory structure
+                app.add_static_dir(Path(__file__).parent / 'static')
+
+                # Add JavaScript and CSS files to HTML pages,
+                # the paths are relative to _static/
+                app.add_js_file('js/my_extension.js')
+                app.add_css_file('css/my_extension.css')
+
+        .. versionadded:: 9.1
+        """
+        path = Path(path)
+        logger.debug("[app] adding static_dir: '%s'", path)
+        self.registry.add_static_dir(path)
+
     def add_latex_package(
         self, packagename: str, options: str | None = None, after_hyperref: bool = False
     ) -> None:
