@@ -33,7 +33,10 @@ from sphinx import __display_version__, package_dir
 from sphinx.builders import Builder
 from sphinx.config import Config
 from sphinx.errors import PycodeError
-from sphinx.ext.autodoc.importer import import_module
+from sphinx.ext.autodoc._dynamic._importer import _import_module
+from sphinx.ext.autodoc._dynamic._member_finder import _filter_enum_dict, unmangle
+from sphinx.ext.autodoc._dynamic._mock import ismock, undecorate
+from sphinx.ext.autodoc._sentinels import INSTANCE_ATTR, SLOTS_ATTR
 from sphinx.ext.autosummary import (
     ImportExceptionGroup,
     _get_documenter,
@@ -45,7 +48,14 @@ from sphinx.pycode import ModuleAnalyzer
 from sphinx.registry import SphinxComponentRegistry
 from sphinx.util import logging, rst
 from sphinx.util._pathlib import _StrPath
-from sphinx.util.inspect import getall, safe_getattr
+from sphinx.util.inspect import (
+    getall,
+    getannotations,
+    getmro,
+    getslots,
+    isenumclass,
+    safe_getattr,
+)
 from sphinx.util.osutil import ensuredir
 from sphinx.util.template import SphinxTemplateLoader
 
@@ -57,7 +67,7 @@ if TYPE_CHECKING:
 
     from sphinx.application import Sphinx
     from sphinx.events import EventManager
-    from sphinx.ext.autodoc import Documenter
+    from sphinx.ext.autodoc._property_types import _AutodocObjType
 
 logger = logging.getLogger(__name__)
 
@@ -96,34 +106,6 @@ class AutosummaryEntry(NamedTuple):
     recursive: bool
 
 
-def setup_documenters(app: Sphinx) -> None:
-    from sphinx.ext.autodoc import (
-        AttributeDocumenter,
-        ClassDocumenter,
-        DataDocumenter,
-        DecoratorDocumenter,
-        ExceptionDocumenter,
-        FunctionDocumenter,
-        MethodDocumenter,
-        ModuleDocumenter,
-        PropertyDocumenter,
-    )
-
-    documenters: list[type[Documenter]] = [
-        ModuleDocumenter,
-        ClassDocumenter,
-        ExceptionDocumenter,
-        DataDocumenter,
-        FunctionDocumenter,
-        MethodDocumenter,
-        AttributeDocumenter,
-        DecoratorDocumenter,
-        PropertyDocumenter,
-    ]
-    for documenter in documenters:
-        app.registry.add_documenter(documenter.objtype, documenter)
-
-
 def _underline(title: str, line: str = '=') -> str:
     if '\n' in title:
         msg = 'Can only underline single lines'
@@ -211,20 +193,18 @@ class ModuleScanner:
         *,
         config: Config,
         events: EventManager,
-        registry: SphinxComponentRegistry,
     ) -> None:
         self.config = config
         self.events = events
-        self.registry = registry
         self.object = obj
 
     def get_object_type(self, name: str, value: Any) -> str:
-        return _get_documenter(value, self.object, registry=self.registry).objtype
+        return _get_documenter(value, self.object)
 
-    def is_skipped(self, name: str, value: Any, objtype: str) -> bool:
+    def is_skipped(self, name: str, value: Any, obj_type: _AutodocObjType) -> bool:
         try:
             return self.events.emit_firstresult(
-                'autodoc-skip-member', objtype, name, value, False, {}
+                'autodoc-skip-member', obj_type, name, value, False, {}
             )
         except Exception as exc:
             logger.warning(
@@ -252,7 +232,7 @@ class ModuleScanner:
             except AttributeError:
                 value = None
 
-            objtype = self.get_object_type(name, value)
+            objtype = _get_documenter(value, self.object)
             if self.is_skipped(name, value, objtype):
                 continue
 
@@ -311,15 +291,14 @@ def generate_autosummary_content(
     *,
     config: Config,
     events: EventManager,
-    registry: SphinxComponentRegistry,
 ) -> str:
-    doc = _get_documenter(obj, parent, registry=registry)
+    obj_type = _get_documenter(obj, parent)
 
     ns: dict[str, Any] = {}
     ns.update(context)
 
-    if doc.objtype == 'module':
-        scanner = ModuleScanner(obj, config=config, events=events, registry=registry)
+    if obj_type == 'module':
+        scanner = ModuleScanner(obj, config=config, events=events)
         ns['members'] = scanner.scan(imported_members)
 
         respect_module_all = not config.autosummary_ignore_module_all
@@ -328,30 +307,27 @@ def generate_autosummary_content(
         )
 
         ns['functions'], ns['all_functions'] = _get_members(
-            doc,
+            obj_type,
             obj,
             {'function'},
             config=config,
             events=events,
-            registry=registry,
             imported=imported_members,
         )
         ns['classes'], ns['all_classes'] = _get_members(
-            doc,
+            obj_type,
             obj,
             {'class'},
             config=config,
             events=events,
-            registry=registry,
             imported=imported_members,
         )
         ns['exceptions'], ns['all_exceptions'] = _get_members(
-            doc,
+            obj_type,
             obj,
             {'exception'},
             config=config,
             events=events,
-            registry=registry,
             imported=imported_members,
         )
         ns['attributes'], ns['all_attributes'] = _get_module_attrs(name, ns['members'])
@@ -374,12 +350,11 @@ def generate_autosummary_content(
             # Otherwise, use get_modules method normally
             if respect_module_all and '__all__' in dir(obj):
                 imported_modules, all_imported_modules = _get_members(
-                    doc,
+                    obj_type,
                     obj,
                     {'module'},
                     config=config,
                     events=events,
-                    registry=registry,
                     imported=True,
                 )
                 skip += all_imported_modules
@@ -393,34 +368,32 @@ def generate_autosummary_content(
             )
             ns['modules'] = imported_modules + modules
             ns['all_modules'] = all_imported_modules + all_modules
-    elif doc.objtype == 'class':
+    elif obj_type == 'class':
         ns['members'] = dir(obj)
         ns['inherited_members'] = set(dir(obj)) - set(obj.__dict__.keys())
         ns['methods'], ns['all_methods'] = _get_members(
-            doc,
+            obj_type,
             obj,
             {'method'},
             config=config,
             events=events,
-            registry=registry,
             include_public={'__init__'},
         )
         ns['attributes'], ns['all_attributes'] = _get_members(
-            doc,
+            obj_type,
             obj,
             {'attribute', 'property'},
             config=config,
             events=events,
-            registry=registry,
         )
 
     if modname is None or qualname is None:
         modname, qualname = _split_full_qualified_name(name)
 
-    if doc.objtype in {'method', 'attribute', 'property'}:
+    if obj_type in {'method', 'attribute', 'property'}:
         ns['class'] = qualname.rsplit('.', 1)[0]
 
-    if doc.objtype == 'class':
+    if obj_type == 'class':
         shortname = qualname
     else:
         shortname = qualname.rsplit('.', 1)[-1]
@@ -430,19 +403,21 @@ def generate_autosummary_content(
     ns['objname'] = qualname
     ns['name'] = shortname
 
-    ns['objtype'] = doc.objtype
+    ns['objtype'] = obj_type
     ns['underline'] = len(name) * '='
 
     if template_name:
         return template.render(template_name, ns)
     else:
-        return template.render(doc.objtype, ns)
+        return template.render(obj_type, ns)
 
 
-def _skip_member(obj: Any, name: str, objtype: str, *, events: EventManager) -> bool:
+def _skip_member(
+    obj: Any, name: str, obj_type: _AutodocObjType, *, events: EventManager
+) -> bool:
     try:
         return events.emit_firstresult(
-            'autodoc-skip-member', objtype, name, obj, False, {}
+            'autodoc-skip-member', obj_type, name, obj, False, {}
         )
     except Exception as exc:
         logger.warning(
@@ -458,8 +433,76 @@ def _skip_member(obj: Any, name: str, objtype: str, *, events: EventManager) ->
 
 
 def _get_class_members(obj: Any) -> dict[str, Any]:
-    members = sphinx.ext.autodoc.importer.get_class_members(obj, None, safe_getattr)
-    return {name: member.object for name, member in members.items()}
+    """Get members and attributes of target class."""
+    # TODO: Simplify
+    # the members directly defined in the class
+    obj_dict = safe_getattr(obj, '__dict__', {})
+
+    members_simpler: dict[str, Any] = {}
+
+    # enum members
+    if isenumclass(obj):
+        for name, defining_class, value in _filter_enum_dict(
+            obj, safe_getattr, obj_dict
+        ):
+            # the order of occurrence of *name* matches obj's MRO,
+            # allowing inherited attributes to be shadowed correctly
+            if unmangled := unmangle(defining_class, name):
+                members_simpler[unmangled] = value
+
+    # members in __slots__
+    try:
+        subject___slots__ = getslots(obj)
+        if subject___slots__:
+            for name in subject___slots__:
+                members_simpler[name] = SLOTS_ATTR
+    except (TypeError, ValueError):
+        pass
+
+    # other members
+    for name in dir(obj):
+        try:
+            value = safe_getattr(obj, name)
+            if ismock(value):
+                value = undecorate(value)
+
+            unmangled = unmangle(obj, name)
+            if unmangled and unmangled not in members_simpler:
+                members_simpler[unmangled] = value
+        except AttributeError:
+            continue
+
+    try:
+        for cls in getmro(obj):
+            try:
+                modname = safe_getattr(cls, '__module__')
+                qualname = safe_getattr(cls, '__qualname__')
+            except AttributeError:
+                qualname = None
+                analyzer = None
+            else:
+                try:
+                    analyzer = ModuleAnalyzer.for_module(modname)
+                    analyzer.analyze()
+                except PycodeError:
+                    analyzer = None
+
+            # annotation only member (ex. attr: int)
+            for name in getannotations(cls):
+                unmangled = unmangle(cls, name)
+                if unmangled and unmangled not in members_simpler:
+                    members_simpler[unmangled] = INSTANCE_ATTR
+
+            # append or complete instance attributes (cf. self.attr1) if analyzer knows
+            if analyzer:
+                for ns, name in analyzer.attr_docs:
+                    if ns == qualname and name not in members_simpler:
+                        # otherwise unknown instance attribute
+                        members_simpler[name] = INSTANCE_ATTR
+    except AttributeError:
+        pass
+
+    return members_simpler
 
 
 def _get_module_members(obj: Any, *, config: Config) -> dict[str, Any]:
@@ -473,36 +516,35 @@ def _get_module_members(obj: Any, *, config: Config) -> dict[str, Any]:
 
 
 def _get_all_members(
-    doc: type[Documenter], obj: Any, *, config: Config
+    obj_type: _AutodocObjType, obj: Any, *, config: Config
 ) -> dict[str, Any]:
-    if doc.objtype == 'module':
+    if obj_type == 'module':
         return _get_module_members(obj, config=config)
-    elif doc.objtype == 'class':
+    elif obj_type == 'class':
         return _get_class_members(obj)
     return {}
 
 
 def _get_members(
-    doc: type[Documenter],
+    obj_type: _AutodocObjType,
     obj: Any,
     types: set[str],
     *,
     config: Config,
     events: EventManager,
-    registry: SphinxComponentRegistry,
     include_public: Set[str] = frozenset(),
     imported: bool = True,
 ) -> tuple[list[str], list[str]]:
     items: list[str] = []
     public: list[str] = []
 
-    all_members = _get_all_members(doc, obj, config=config)
+    all_members = _get_all_members(obj_type, obj, config=config)
     for name, value in all_members.items():
-        documenter = _get_documenter(value, obj, registry=registry)
-        if documenter.objtype in types:
+        obj_type = _get_documenter(value, obj)
+        if obj_type in types:
             # skip imported members if expected
             if imported or getattr(value, '__module__', None) == obj.__name__:
-                skipped = _skip_member(value, name, documenter.objtype, events=events)
+                skipped = _skip_member(value, name, obj_type, events=events)
                 if skipped is True:
                     pass
                 elif skipped is False:
@@ -548,7 +590,7 @@ def _get_modules(
             continue
         fullname = f'{name}.{modname}'
         try:
-            module = import_module(fullname)
+            module = _import_module(fullname)
         except ImportError:
             pass
         else:
@@ -583,7 +625,7 @@ def generate_autosummary_docs(
 
     showed_sources = sorted(sources)
     if len(showed_sources) > 20:
-        showed_sources = showed_sources[:10] + ['...'] + showed_sources[-10:]
+        showed_sources = [*showed_sources[:10], '...', *showed_sources[-10:]]
     logger.info(
         __('[autosummary] generating autosummary for: %s'), ', '.join(showed_sources)
     )
@@ -655,7 +697,6 @@ def generate_autosummary_docs(
             qualname,
             config=app.config,
             events=app.events,
-            registry=app.registry,
         )
 
         file_path = Path(path, filename_map.get(name, name) + suffix)
@@ -719,7 +760,7 @@ def find_autosummary_in_docstring(
     See `find_autosummary_in_lines`.
     """
     try:
-        real_name, obj, parent, modname = import_by_name(name)
+        _real_name, obj, _parent, _modname = import_by_name(name)
         lines = pydoc.getdoc(obj).splitlines()
         return find_autosummary_in_lines(lines, module=name, filename=filename)
     except AttributeError:
@@ -919,7 +960,6 @@ def main(argv: Sequence[str] = (), /) -> None:
 
     app = DummyApplication(sphinx.locale.get_translator())
     logging.setup(app, sys.stdout, sys.stderr)  # type: ignore[arg-type]
-    setup_documenters(app)  # type: ignore[arg-type]
     args = get_parser().parse_args(argv or sys.argv[1:])
 
     if args.templates:
